@@ -95,7 +95,7 @@ class TextSystem(object):
             cv2.imwrite("./output/img_crop_%d.jpg" % bno, img_crop_list[bno])
             logger.info(bno, rec_res[bno])
 
-    def __call__(self, img):
+    def __call__(self, img, cls=True):
         ori_im = img.copy()
         dt_boxes, elapse = self.text_detector(img)
         logger.info("dt_boxes num : {}, elapse : {}".format(
@@ -110,11 +110,12 @@ class TextSystem(object):
             tmp_box = copy.deepcopy(dt_boxes[bno])
             img_crop = self.get_rotate_crop_image(ori_im, tmp_box)
             img_crop_list.append(img_crop)
-            
-        img_crop_list, angle_list, elapse = self.text_classifier(
-            img_crop_list)
-        logger.info("cls num  : {}, elapse : {}".format(
-            len(img_crop_list), elapse))
+        
+        if cls:  
+            img_crop_list, angle_list, elapse = self.text_classifier(
+                img_crop_list)
+            logger.info("cls num  : {}, elapse : {}".format(
+                len(img_crop_list), elapse))
 
         rec_res, elapse = self.text_recognizer(img_crop_list)
         logger.info("rec_res num  : {}, elapse : {}".format(
@@ -360,7 +361,7 @@ def main():
             logger.info("error in loading image:{}".format(image_file))
             continue
         starttime = time.time()
-        dt_boxes, rec_res = text_sys(img)
+        dt_boxes, rec_res = text_sys(img, cls=config['use_cls'])
         elapse = time.time() - starttime
         logger.info("Predict time of %s: %.3fs" % (image_file, elapse))
 
