@@ -21,8 +21,8 @@ import numpy as np
 import requests
 from tqdm import tqdm
 import shutil
+from PIL import Image
 
-import hydra
 from omegaconf import OmegaConf
 from hydra.experimental import compose, initialize_config_dir
 
@@ -31,6 +31,7 @@ from ucr.utils.logging import get_logger
 
 logger = get_logger()
 from ucr.utils.utility import check_and_read_gif, get_image_file_list
+from ucr.utils.annotation import draw_ocr_box_txt, draw_text_det_res
 
 __all__ = ['UCR']
 
@@ -71,7 +72,8 @@ class UCR(infer_system.TextSystem):
             overrides = [f"{k}={v}" for k, v in model_urls[model_type]['det'][det_algorithm].items() if k!='url']
             overrides.extend(args.det_overrides)
             cfg = compose(config_name=args.det_config_name, overrides=overrides)    
-            print(cfg.pretty())    
+            logger.info("Detection config:\n{}\n".format(cfg.pretty()))    
+            
             config_det = OmegaConf.to_container(cfg)
             model_type = backend + '_' + type
             
@@ -79,18 +81,24 @@ class UCR(infer_system.TextSystem):
             model_type = 'torch_mobile' if lang != 'ch_sim' else model_type
             overrides = [f"{k}={v}" for k, v in model_urls[model_type]['rec'][lang].items() if k!='url']
             overrides.extend(args.rec_overrides)
-            cfg = compose(config_name=args.rec_config_name, overrides=overrides)        
+            cfg = compose(config_name=args.rec_config_name, overrides=overrides)      
+            logger.info("Recognition config:\n{}\n".format(cfg.pretty()))    
+                  
             config_rec = OmegaConf.to_container(cfg)
             model_type = backend + '_' + type
             
         with initialize_config_dir(config_dir=conf_location, job_name="infer_cls"):
             overrides = [f"{k}={v}" for k, v in model_urls['torch_mobile']['cls'].items() if k!='url']
             overrides.extend(args.cls_overrides)
-            cfg = compose(config_name=args.cls_config_name, overrides=overrides)        
+            cfg = compose(config_name=args.cls_config_name, overrides=overrides)    
+            logger.info("Classification config:\n{}\n".format(cfg.pretty()))    
+                    
             config_cls = OmegaConf.to_container(cfg)
         
         with initialize_config_dir(config_dir=conf_location, job_name="infer_system"):
-            cfg = compose(config_name="infer_system", overrides=args.system_overrides)        
+            cfg = compose(config_name="infer_system", overrides=args.system_overrides)    
+            logger.info("End-to-end config:\n{}\n".format(cfg.pretty()))    
+                    
             config = OmegaConf.to_container(cfg)
             
         assert model_type in SUPPORT_MODEL_TYPE, 'TYPE_BACKEND must be of {} format, but got {}'.format(
@@ -113,95 +121,190 @@ class UCR(infer_system.TextSystem):
             config_det['model_location'] = os.path.join(det_path, 'model.pt')
             model_type = backend + '_' + type
         else:
-            config_det['model_location'] = hydra.utils.to_absolute_path(config_det['model_location']) 
+            config_det['model_location'] = config_det['model_location'] # add abs path in parser args. 
         
         if not config_rec['model_location']:
             model_type = 'torch_mobile' if lang != 'ch_sim' else model_type
             rec_path = maybe_download(os.path.join(BASE_DIR, '{}/rec/{}'.format(VERSION, lang)), model_urls[model_type]['rec'][lang]['url'], force_download)
             config_rec['model_location'] = os.path.join(rec_path, 'model.pt')   
-            config_rec['font_path'] = hydra.utils.to_absolute_path(config_rec['font_path'])  # TODO: Zip both font_path and char_dict_location in model_url
-            config_rec['char_dict_location'] = hydra.utils.to_absolute_path(config_rec['char_dict_location'])   
+            
+            __dir__ = os.path.dirname(__file__)
+            config_rec['font_path'] = os.path.join(__dir__, config_rec['font_path'])  # TODO: Zip both font_path and char_dict_location in model_url
+            config_rec['char_dict_location'] = os.path.join(__dir__, config_rec['char_dict_location'])   
         else:
-            config_rec['model_location'] = hydra.utils.to_absolute_path(config_rec['model_location'])  
-            config_rec['font_path'] = hydra.utils.to_absolute_path(config_rec['font_path'])  
-            config_rec['char_dict_location'] = hydra.utils.to_absolute_path(config_rec['char_dict_location'])       
+            config_rec['model_location'] = config_rec['model_location'] # add abs path in parser args. 
+            config_rec['font_path'] = config_rec['font_path'] # add abs path in .yaml file  
+            config_rec['char_dict_location'] = config_rec['char_dict_location'] # add abs path in .yaml file       
             
         if not config_cls['model_location']:
             cls_path = maybe_download(os.path.join(BASE_DIR, '{}/cls'.format(VERSION)), model_urls['torch_mobile']['cls']['url'], force_download)
             config_cls['model_location'] = os.path.join(cls_path, 'model.pt')  
         else:
-            config_cls['model_location'] = hydra.utils.to_absolute_path(config_cls['model_location']) 
+            config_cls['model_location'] = config_cls['model_location'] # add abs path in parser args.
 
         config['Detection'] = config_det
         config['Recognition'] = config_rec
         config['Classification'] = config_cls
         
+        self.merge_boxes = config["merge_boxes"]
+        self.drop_score = config["drop_score"]
+        self.font_path = config_rec['font_path']
+        
         super().__init__(config)
 
-    def predict(self, img, det=True, rec=True, cls=False):
+    def predict(self, input, save_output=True, output='output/', det=True, rec=True, cls=False):
         """
         ocr with paddleocr
         args：
-            img: img for ocr, support ndarray, img_path and list or ndarray
+            input: input for ocr, support ndarray, img_path and list or ndarray
             det: use text detection or not, if false, only rec will be exec. default is True
             rec: use text recognition or not, if false, only det will be exec. default is True
         """
-        assert isinstance(img, (np.ndarray, list, str))
-        if isinstance(img, list) and det == True:
+        assert isinstance(input, (np.ndarray, list, str))
+        if isinstance(input, list) and det == True:
             logger.error('When input a list of images, det must be false')
             exit(0)
-
-        if isinstance(img, str):
+        
+        if isinstance(input, str):
             # download net image
-            if img.startswith('http') and img.endswith('.jpg'):
-                download_with_progressbar(img, 'tmp.jpg')
-                img = 'tmp.jpg'
-            image_file = img
-            img, flag = check_and_read_gif(image_file)
-            if not flag:
-                with open(image_file, 'rb') as f:
-                    np_arr = np.frombuffer(f.read(), dtype=np.uint8)
-                    img = cv2.imdecode(np_arr, cv2.IMREAD_COLOR)
-            if img is None:
-                logger.error("error in loading image:{}".format(image_file))
-                return None
-        if isinstance(img, np.ndarray) and len(img.shape) == 2:
-            img = cv2.cvtColor(img, cv2.COLOR_GRAY2BGR)
+            if input.startswith('http') and input.endswith('.jpg'):
+                download_with_progressbar(input, 'tmp.jpg')
+                input = 'tmp.jpg'
+                
+            img_list = get_image_file_list(input)
+            
+            rec_dict = {}
+            out_dict={}
+            
+            for image_file in tqdm(img_list):
+                key = os.path.basename(image_file)
+                img, flag = check_and_read_gif(image_file)
+                if not flag:
+                    img = cv2.imread(image_file)
+                if img is None:
+                    logger.info("error in loading image:{}".format(image_file))
+                    continue
+                
+                if det and rec:
+                    dt_boxes, rec_res = self.__call__(img, cls)
+                    if self.merge_boxes:
+                        rec_res = rec_res[0:1]
+                    value = [[box.tolist(), res] for box, res in zip(dt_boxes, rec_res)]
+                    out_dict[key] = value
+                    
+                    if save_output:
+                        image = Image.fromarray(cv2.cvtColor(img, cv2.COLOR_BGR2RGB))
+                        boxes = dt_boxes
+                        txts = [rec_res[i][0] for i in range(len(rec_res))]
+                        scores = [rec_res[i][1] for i in range(len(rec_res))]
+
+                        draw_img = draw_ocr_box_txt(
+                            image,
+                            boxes,
+                            txts,
+                            scores,
+                            drop_score=self.drop_score,
+                            font_path=self.font_path)
+                        
+                        if not os.path.exists(output):
+                            os.makedirs(output)
+                        cv2.imwrite(
+                            os.path.join(output, key),
+                            draw_img[:, :, ::-1])
+                        logger.info("OCR ouput image is saved in {}".format(
+                            os.path.join(output, key)))
+                        
+                elif det and not rec:
+                    dt_boxes, elapse = self.text_detector(img)
+                    if dt_boxes is not None:
+                        value = [box.tolist() for box in dt_boxes]
+                        out_dict[key] = value
+                        
+                        if save_output:
+                            src_im = draw_text_det_res(dt_boxes, image_file)
+                            
+                            if not os.path.exists(output):
+                                os.makedirs(output)
+                            img_path = os.path.join(output,
+                                                    "det_res_{}".format(key))
+                            cv2.imwrite(img_path, src_im)
+                            logger.info("Detection output image is saved in {}".format(img_path))
+                else:
+                    rec_dict[key] = img 
+            
+            if rec_dict:
+                img = rec_dict.values()
+                if cls:
+                    img, cls_res, elapse = self.text_classifier(img)
+                    if not rec:
+                        cls_output = {k:v for k,v in zip(rec_dict.keys(), cls_res)}
+                        
+                        if save_output:
+                            for key, val in cls_output.items():
+                                logger.info("Classification result of {}:{}".format(key, val))
+                                
+                        return cls_output               
+                if rec:    
+                    rec_res, elapse = self.text_recognizer(img)
+                    rec_output = {k:v for k,v in zip(rec_dict.keys(), rec_res)} 
+                    
+                    if save_output:
+                        for key, val in rec_output.items():
+                            logger.info("Recognition result of {}:{}".format(key, val))
+                        
+                    return rec_output
+            else:
+                return out_dict
+            
+        key = 'numpy_array'
+        if isinstance(input, np.ndarray) and len(input.shape) == 2:
+            input = cv2.cvtColor(input, cv2.COLOR_GRAY2BGR)        
         if det and rec:
-            dt_boxes, rec_res = self.__call__(img)
-            return [[box.tolist(), res] for box, res in zip(dt_boxes, rec_res)]
+            dt_boxes, rec_res = self.__call__(input, cls)
+            if self.merge_boxes:
+                rec_res = rec_res[0:1]
+            value = [[box.tolist(), res] for box, res in zip(dt_boxes, rec_res)]
+            return {key: value}
         elif det and not rec:
-            dt_boxes, elapse = self.text_detector(img)
+            dt_boxes, elapse = self.text_detector(input)
             if dt_boxes is None:
                 return None
-            return [box.tolist() for box in dt_boxes]
+            value = [box.tolist() for box in dt_boxes]
+            return {key: value}
         else:
-            if not isinstance(img, list):
-                img = [img]
+            key = 'rec_dict'
+            if not isinstance(input, list):
+                input = [input]
             if cls:
-                img, cls_res, elapse = self.text_classifier(img)
+                input, cls_res, elapse = self.text_classifier(input)
                 if not rec:
-                    return cls_res
-            rec_res, elapse = self.text_recognizer(img)
-            return rec_res
-   
+                    key = 'cls_dict'
+                    return {key: cls_res}
+            if rec:
+                rec_res, elapse = self.text_recognizer(input)
+                return {key: rec_res}
+            else:
+                return None
+
+
 def main():
-    
     args = parse_args(mMain=True)
     input_location = args.input_location
     if input_location.startswith('http') and input_location.endswith('.jpg'):
         download_with_progressbar(input_location, 'tmp.jpg')
-        image_file_list = ['tmp.jpg']
+        img_list = ['tmp.jpg']
     else:
-        image_file_list = get_image_file_list(input_location)   
-    if len(image_file_list) == 0:
+        img_list = get_image_file_list(input_location)   
+    if len(img_list) == 0:
         logger.error('no images find in {}'.format(args.input_location))
         return 
     
     ocr_engine = UCR(**(args.__dict__))
-    for img_path in image_file_list:
+    for img_path in img_list:
         logger.info('{}{}{}'.format('*' * 10, img_path, '*' * 10))
         result = ocr_engine.predict(img_path,
+                                args.save_output,
+                                args.output_location,
                                 det=args.det,
                                 rec=args.rec,
                                 cls=args.cls)
@@ -256,6 +359,7 @@ def parse_args(mMain=True, add_help=True):
         parser.add_argument("--force_download", type=str2bool, default=False)
         parser.add_argument("--input_location", type=str, default='input_dir/')
         parser.add_argument("--output_location", type=str, default='output_dir/')
+        parser.add_argument("--save_output", type=str2bool, default=True)
         parser.add_argument("--device", type=str, default='cpu')
         parser.add_argument("--lang", type=str, default='ch_sim')
         parser.add_argument("--backend", type=str, default='torch')
@@ -352,8 +456,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_server',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/simfang.ttf',
-                'char_dict_location': 'ucr/utils/dict/ench_dict.txt',
+                'font_path': 'utils/fonts/simfang.ttf',
+                'char_dict_location': 'utils/dict/ench_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_server/rec_ench_ppocr_server.zip',                
             }
@@ -375,8 +479,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/simfang.ttf',
-                'char_dict_location': 'ucr/utils/dict/ench_dict.txt',
+                'font_path': 'utils/fonts/simfang.ttf',
+                'char_dict_location': 'utils/dict/ench_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_ench_ppocr_mobile.zip',                
             },
@@ -384,8 +488,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/only_en.ttf',
-                'char_dict_location': 'ucr/utils/dict/en_dict.txt',
+                'font_path': 'utils/fonts/only_en.ttf',
+                'char_dict_location': 'utils/dict/en_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_en_number_mobile.zip',                
             },
@@ -393,8 +497,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/french.ttf',
-                'char_dict_location': 'ucr/utils/dict/french_dict.txt',
+                'font_path': 'utils/fonts/french.ttf',
+                'char_dict_location': 'utils/dict/french_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_french_mobile.zip',                
             },
@@ -402,8 +506,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/german.ttf',
-                'char_dict_location': 'ucr/utils/dict/german_dict.txt',
+                'font_path': 'utils/fonts/german.ttf',
+                'char_dict_location': 'utils/dict/german_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_german_mobile.zip',                
             },
@@ -411,8 +515,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/korean.ttf',
-                'char_dict_location': 'ucr/utils/dict/korean_dict.txt',
+                'font_path': 'utils/fonts/korean.ttf',
+                'char_dict_location': 'utils/dict/korean_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_korean_mobile.zip',                
             },
@@ -420,8 +524,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/japan.ttc',
-                'char_dict_location': 'ucr/utils/dict/japan_dict.txt',
+                'font_path': 'utils/fonts/japan.ttc',
+                'char_dict_location': 'utils/dict/japan_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_japan_mobile.zip',                
             },
@@ -429,8 +533,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/chinese_cht.ttf',
-                'char_dict_location': 'ucr/utils/dict/chinese_cht_dict.txt',
+                'font_path': 'utils/fonts/chinese_cht.ttf',
+                'char_dict_location': 'utils/dict/chinese_cht_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_chinese_cht_mobile.zip',                
             },
@@ -438,8 +542,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/italian.ttf',
-                'char_dict_location': 'ucr/utils/dict/it_dict.txt',
+                'font_path': 'utils/fonts/italian.ttf',
+                'char_dict_location': 'utils/dict/it_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_it_mobile.zip',                
             },
@@ -447,8 +551,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/xi.ttf',
-                'char_dict_location': 'ucr/utils/dict/spanish_dict.txt',
+                'font_path': 'utils/fonts/xi.ttf',
+                'char_dict_location': 'utils/dict/spanish_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_xi_mobile.zip',                
             },
@@ -456,8 +560,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/portugese.ttf',
-                'char_dict_location': 'ucr/utils/dict/pu_dict.txt',
+                'font_path': 'utils/fonts/portugese.ttf',
+                'char_dict_location': 'utils/dict/pu_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_pu_mobile.zip',                
             },
@@ -465,8 +569,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/russian.ttf',
-                'char_dict_location': 'ucr/utils/dict/ru_dict.txt',
+                'font_path': 'utils/fonts/russian.ttf',
+                'char_dict_location': 'utils/dict/ru_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_ru_mobile.zip',                
             },
@@ -474,8 +578,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/arabic.ttf',
-                'char_dict_location': 'ucr/utils/dict/ar_dict.txt',
+                'font_path': 'utils/fonts/arabic.ttf',
+                'char_dict_location': 'utils/dict/ar_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_ar_mobile.zip',                
             },
@@ -483,8 +587,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/hindi.ttf',
-                'char_dict_location': 'ucr/utils/dict/hi_dict.txt',
+                'font_path': 'utils/fonts/hindi.ttf',
+                'char_dict_location': 'utils/dict/hi_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_hi_mobile.zip',                
             },
@@ -492,8 +596,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/uyghur.ttf',
-                'char_dict_location': 'ucr/utils/dict/ug_dict.txt',
+                'font_path': 'utils/fonts/uyghur.ttf',
+                'char_dict_location': 'utils/dict/ug_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_ug_mobile.zip',                
             },
@@ -501,8 +605,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/persian.ttf',
-                'char_dict_location': 'ucr/utils/dict/fa_dict.txt',
+                'font_path': 'utils/fonts/persian.ttf',
+                'char_dict_location': 'utils/dict/fa_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_fa_mobile.zip',                
             },
@@ -510,8 +614,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/urdu.ttf',
-                'char_dict_location': 'ucr/utils/dict/ur_dict.txt',
+                'font_path': 'utils/fonts/urdu.ttf',
+                'char_dict_location': 'utils/dict/ur_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_ur_mobile.zip',                
             },
@@ -519,8 +623,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/serbian.ttf',
-                'char_dict_location': 'ucr/utils/dict/rs_dict.txt',
+                'font_path': 'utils/fonts/serbian.ttf',
+                'char_dict_location': 'utils/dict/rs_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_rs_mobile.zip',                
             },
@@ -528,8 +632,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/serbian.ttf',
-                'char_dict_location': 'ucr/utils/dict/oc_dict.txt',
+                'font_path': 'utils/fonts/serbian.ttf',
+                'char_dict_location': 'utils/dict/oc_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_oc_mobile.zip',                
             },
@@ -537,8 +641,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/marathi.ttf',
-                'char_dict_location': 'ucr/utils/dict/mr_dict.txt',
+                'font_path': 'utils/fonts/marathi.ttf',
+                'char_dict_location': 'utils/dict/mr_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_mr_mobile.zip',                
             },
@@ -546,8 +650,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/nepali.ttf',
-                'char_dict_location': 'ucr/utils/dict/ne_dict.txt',
+                'font_path': 'utils/fonts/nepali.ttf',
+                'char_dict_location': 'utils/dict/ne_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_ne_mobile.zip',                
             },
@@ -555,8 +659,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/serbian.ttf',
-                'char_dict_location': 'ucr/utils/dict/rsc_dict.txt',
+                'font_path': 'utils/fonts/serbian.ttf',
+                'char_dict_location': 'utils/dict/rsc_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_rsc_mobile.zip',                
             },
@@ -564,8 +668,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/serbian.ttf',
-                'char_dict_location': 'ucr/utils/dict/bg_dict.txt',
+                'font_path': 'utils/fonts/serbian.ttf',
+                'char_dict_location': 'utils/dict/bg_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_bg_mobile.zip',                
             },
@@ -573,8 +677,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/serbian.ttf',
-                'char_dict_location': 'ucr/utils/dict/uk_dict.txt',
+                'font_path': 'utils/fonts/serbian.ttf',
+                'char_dict_location': 'utils/dict/uk_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_uk_mobile.zip',                
             },
@@ -582,8 +686,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/serbian.ttf',
-                'char_dict_location': 'ucr/utils/dict/be_dict.txt',
+                'font_path': 'utils/fonts/serbian.ttf',
+                'char_dict_location': 'utils/dict/be_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_be_mobile.zip',                
             },
@@ -591,8 +695,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/telugu.ttf',
-                'char_dict_location': 'ucr/utils/dict/te_dict.txt',
+                'font_path': 'utils/fonts/telugu.ttf',
+                'char_dict_location': 'utils/dict/te_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_te_mobile.zip',                
             },
@@ -600,8 +704,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/kannada.ttf',
-                'char_dict_location': 'ucr/utils/dict/ka_dict.txt',
+                'font_path': 'utils/fonts/kannada.ttf',
+                'char_dict_location': 'utils/dict/ka_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_ka_mobile.zip',                
             },
@@ -609,8 +713,8 @@ model_urls = {
                 'preprocess': 'rec_ctc',
                 'architecture': 'rec_ppocr_mobile',
                 'postprocess': 'rec_ctc',
-                'font_path': 'ucr/utils/fonts/tamil.ttf',
-                'char_dict_location': 'ucr/utils/dict/ta_dict.txt',
+                'font_path': 'utils/fonts/tamil.ttf',
+                'char_dict_location': 'utils/dict/ta_dict.txt',
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR/torch_mobile/rec_ta_mobile.zip',                
             }
